@@ -2,7 +2,7 @@ use std::ops::{AddAssign, DivAssign, MulAssign};
 
 use arrow::array::PrimitiveArray;
 use arrow::types::NativeType;
-use num::Float;
+use num_traits::Float;
 
 use crate::trusted_len::TrustedLen;
 use crate::utils::CustomIterTools;
@@ -208,6 +208,7 @@ mod test {
     use super::*;
     const ALPHA: f64 = 0.5;
     const EPS: f64 = 1e-15;
+    use std::f64::consts::SQRT_2;
 
     const XS: [Option<f64>; 7] = [
         Some(1.0),
@@ -225,117 +226,117 @@ mod test {
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, true, true, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(3.55555555555555580227),
-                Some(4.24489795918367374128),
-                Some(7.18222222222222139720),
-                Some(3.79604578563995787022),
-                Some(2.46712018140589606219),
-                Some(2.47603695207390428479),
+                Some(0.0),
+                Some(3.555_555_555_555_556),
+                Some(4.244_897_959_183_674),
+                Some(7.182_222_222_222_221),
+                Some(3.796_045_785_639_958),
+                Some(2.467_120_181_405_896),
+                Some(2.476_036_952_073_904_3),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(3.55555555555555580227),
-                Some(4.24489795918367374128),
-                Some(7.18222222222222139720),
-                Some(3.79604578563995787022),
-                Some(2.46712018140589606219),
-                Some(2.47603695207390428479),
+                Some(0.0),
+                Some(3.555_555_555_555_556),
+                Some(4.244_897_959_183_674),
+                Some(7.182_222_222_222_221),
+                Some(3.796_045_785_639_958),
+                Some(2.467_120_181_405_896),
+                Some(2.476_036_952_073_904_3),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, true, false, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(8.00000000000000000000),
-                Some(7.42857142857142882519),
-                Some(11.54285714285714270488),
-                Some(5.88387096774193452120),
-                Some(3.76036866359447063957),
-                Some(3.74353205849268855232),
+                Some(0.0),
+                Some(8.0),
+                Some(7.428_571_428_571_429),
+                Some(11.542_857_142_857_143),
+                Some(5.883_870_967_741_934_5),
+                Some(3.760_368_663_594_470_6),
+                Some(3.743_532_058_492_688_6),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, true, false, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(8.00000000000000000000),
-                Some(7.42857142857142882519),
-                Some(11.54285714285714270488),
-                Some(5.88387096774193452120),
-                Some(3.76036866359447063957),
-                Some(3.74353205849268855232),
+                Some(0.0),
+                Some(8.0),
+                Some(7.428_571_428_571_429),
+                Some(11.542_857_142_857_143),
+                Some(5.883_870_967_741_934_5),
+                Some(3.760_368_663_594_470_6),
+                Some(3.743_532_058_492_688_6),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, false, true, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(4.00000000000000000000),
-                Some(6.00000000000000000000),
-                Some(7.00000000000000000000),
-                Some(3.75000000000000000000),
-                Some(2.43750000000000000000),
-                Some(2.48437500000000000000),
+                Some(0.0),
+                Some(4.0),
+                Some(6.0),
+                Some(7.0),
+                Some(3.75),
+                Some(2.437_5),
+                Some(2.484_375),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(4.00000000000000000000),
-                Some(6.00000000000000000000),
-                Some(7.00000000000000000000),
-                Some(3.75000000000000000000),
-                Some(2.43750000000000000000),
-                Some(2.48437500000000000000),
+                Some(0.0),
+                Some(4.0),
+                Some(6.0),
+                Some(7.0),
+                Some(3.75),
+                Some(2.437_5),
+                Some(2.484_375),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(4.00000000000000000000),
-                Some(6.00000000000000000000),
-                Some(7.00000000000000000000),
-                Some(3.75000000000000000000),
-                Some(2.43750000000000000000),
-                Some(2.48437500000000000000),
+                Some(0.0),
+                Some(4.0),
+                Some(6.0),
+                Some(7.0),
+                Some(3.75),
+                Some(2.437_5),
+                Some(2.484_375),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, false, false, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(8.00000000000000000000),
-                Some(9.60000000000000142109),
-                Some(10.66666666666666607455),
-                Some(5.64705882352941124225),
-                Some(3.65982404692082097242),
-                Some(3.72747252747252755256),
+                Some(0.0),
+                Some(8.0),
+                Some(9.600_000_000_000_001),
+                Some(10.666_666_666_666_666),
+                Some(5.647_058_823_529_411),
+                Some(3.659_824_046_920_821),
+                Some(3.727_472_527_472_527_6),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_var(XS.to_vec(), ALPHA, false, false, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(8.00000000000000000000),
-                Some(9.60000000000000142109),
-                Some(10.66666666666666607455),
-                Some(5.64705882352941124225),
-                Some(3.65982404692082097242),
-                Some(3.72747252747252755256),
+                Some(0.0),
+                Some(8.0),
+                Some(9.600_000_000_000_001),
+                Some(10.666_666_666_666_666),
+                Some(5.647_058_823_529_411),
+                Some(3.659_824_046_920_821),
+                Some(3.727_472_527_472_527_6),
             ]),
             EPS
         );
@@ -343,12 +344,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(7.34693877551020335659),
-                Some(3.55555555555555535818),
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(7.346_938_775_510_203),
+                Some(3.555_555_555_555_555_4),
             ]),
             EPS
         );
@@ -356,12 +357,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(3.92243767313019331411),
-                Some(2.54978854286812728347),
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(3.922_437_673_130_193_3),
+                Some(2.549_788_542_868_127_3),
             ]),
             EPS
         );
@@ -369,12 +370,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(12.85714285714285587403),
-                Some(5.71428571428571441260),
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(12.857_142_857_142_856),
+                Some(5.714_285_714_285_714),
             ]),
             EPS
         );
@@ -382,12 +383,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(14.15999999999999658939),
-                Some(5.03951367781154946357),
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(14.159_999_999_999_997),
+                Some(5.039_513_677_811_549_5),
             ]),
             EPS
         );
@@ -395,12 +396,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, false, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(6.75000000000000000000),
-                Some(3.43750000000000000000),
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(6.75),
+                Some(3.437_5),
             ]),
             EPS
         );
@@ -408,12 +409,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(4.20000000000000017764),
-                Some(3.10000000000000008882),
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(4.2),
+                Some(3.1),
             ]),
             EPS
         );
@@ -421,12 +422,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, false, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(10.80000000000000071054),
-                Some(5.23809523809523813753),
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(10.8),
+                Some(5.238_095_238_095_238),
             ]),
             EPS
         );
@@ -434,12 +435,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, false, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(12.35294117647058875775),
-                Some(5.29914529914529985888),
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(12.352_941_176_470_589),
+                Some(5.299_145_299_145_3),
             ]),
             EPS
         );
@@ -451,12 +452,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, true, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(7.34693877551020335659),
-                Some(3.55555555555555535818)
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(7.346_938_775_510_203),
+                Some(3.555_555_555_555_555_4)
             ]),
             EPS
         );
@@ -464,12 +465,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(3.92243767313019331411),
-                Some(2.54978854286812728347)
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(3.922_437_673_130_193_3),
+                Some(2.549_788_542_868_127_3)
             ]),
             EPS
         );
@@ -477,12 +478,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, true, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(12.85714285714285587403),
-                Some(5.71428571428571441260)
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(12.857_142_857_142_856),
+                Some(5.714_285_714_285_714)
             ]),
             EPS
         );
@@ -490,12 +491,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, true, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(14.15999999999999658939),
-                Some(5.03951367781154946357)
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(14.159_999_999_999_997),
+                Some(5.039_513_677_811_549_5)
             ]),
             EPS
         );
@@ -503,12 +504,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, false, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(6.75000000000000000000),
-                Some(3.43750000000000000000)
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(6.75),
+                Some(3.437_5)
             ]),
             EPS
         );
@@ -516,12 +517,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(4.20000000000000017764),
-                Some(3.10000000000000008882)
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(4.2),
+                Some(3.1)
             ]),
             EPS
         );
@@ -529,12 +530,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, false, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(10.80000000000000071054),
-                Some(5.23809523809523813753)
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(10.8),
+                Some(5.238_095_238_095_238)
             ]),
             EPS
         );
@@ -542,12 +543,12 @@ mod test {
             ewm_cov(XS.to_vec(), YS.to_vec(), ALPHA, false, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(12.35294117647058875775),
-                Some(5.29914529914529985888)
+                Some(0.0),
+                Some(2.0),
+                Some(2.0),
+                Some(2.0),
+                Some(12.352_941_176_470_589),
+                Some(5.299_145_299_145_3)
             ]),
             EPS
         );
@@ -558,104 +559,104 @@ mod test {
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, true, true, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(1.88561808316412671260),
-                Some(2.06031501455085130914),
-                Some(2.67996683229890386713),
-                Some(1.94834437039245145229),
-                Some(1.57070690499720422295),
-                Some(1.57354280274605318191),
+                Some(0.0),
+                Some(1.885_618_083_164_126_7),
+                Some(2.060_315_014_550_851_3),
+                Some(2.679_966_832_298_904),
+                Some(1.948_344_370_392_451_5),
+                Some(1.570_706_904_997_204_2),
+                Some(1.573_542_802_746_053_2),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(1.88561808316412671260),
-                Some(2.06031501455085130914),
-                Some(2.67996683229890386713),
-                Some(1.94834437039245145229),
-                Some(1.57070690499720422295),
-                Some(1.57354280274605318191),
+                Some(0.0),
+                Some(1.885_618_083_164_126_7),
+                Some(2.060_315_014_550_851_3),
+                Some(2.679_966_832_298_904),
+                Some(1.948_344_370_392_451_5),
+                Some(1.570_706_904_997_204_2),
+                Some(1.573_542_802_746_053_2),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, true, false, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.82842712474619029095),
-                Some(2.72554057547698747044),
-                Some(3.39747805627308530063),
-                Some(2.42566917936925907640),
-                Some(1.93916700250248452697),
-                Some(1.93482093706179658632),
+                Some(0.0),
+                Some(2.828_427_124_746_190_3),
+                Some(2.725_540_575_476_987_5),
+                Some(3.397_478_056_273_085_3),
+                Some(2.425_669_179_369_259),
+                Some(1.939_167_002_502_484_5),
+                Some(1.934_820_937_061_796_6),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, true, false, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.82842712474619029095),
-                Some(2.72554057547698747044),
-                Some(3.39747805627308530063),
-                Some(2.42566917936925907640),
-                Some(1.93916700250248452697),
-                Some(1.93482093706179658632),
+                Some(0.0),
+                Some(2.828_427_124_746_190_3),
+                Some(2.725_540_575_476_987_5),
+                Some(3.397_478_056_273_085_3),
+                Some(2.425_669_179_369_259),
+                Some(1.939_167_002_502_484_5),
+                Some(1.934_820_937_061_796_6),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, false, true, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.44948974278317788134),
-                Some(2.64575131106459071617),
-                Some(1.93649167310370851069),
-                Some(1.56124949959959957724),
-                Some(1.57619002661481144578),
+                Some(0.0),
+                Some(2.0),
+                Some(2.449_489_742_783_178),
+                Some(2.645_751_311_064_590_7),
+                Some(1.936_491_673_103_708_5),
+                Some(1.561_249_499_599_599_6),
+                Some(1.576_190_026_614_811_4),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.00000000000000000000),
-                Some(2.44948974278317788134),
-                Some(2.64575131106459071617),
-                Some(1.93649167310370851069),
-                Some(1.56124949959959957724),
-                Some(1.57619002661481144578),
+                Some(0.0),
+                Some(2.0),
+                Some(2.449_489_742_783_178),
+                Some(2.645_751_311_064_590_7),
+                Some(1.936_491_673_103_708_5),
+                Some(1.561_249_499_599_599_6),
+                Some(1.576_190_026_614_811_4),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, false, false, 0, true),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.82842712474619029095),
-                Some(3.09838667696593361711),
-                Some(3.26598632371090413784),
-                Some(2.37635410314401829268),
-                Some(1.91306666034428118905),
-                Some(1.93066634286521066066),
+                Some(0.0),
+                Some(2.828_427_124_746_190_3),
+                Some(3.098_386_676_965_933_6),
+                Some(3.265_986_323_710_904),
+                Some(2.376_354_103_144_018_3),
+                Some(1.913_066_660_344_281_2),
+                Some(1.930_666_342_865_210_7),
             ]),
             EPS
         );
         assert_allclose!(
             ewm_std(XS.to_vec(), ALPHA, false, false, 0, false),
             PrimitiveArray::from([
-                Some(0.00000000000000000000),
-                Some(2.82842712474619029095),
-                Some(3.09838667696593361711),
-                Some(3.26598632371090413784),
-                Some(2.37635410314401829268),
-                Some(1.91306666034428118905),
-                Some(1.93066634286521066066),
+                Some(0.0),
+                Some(2.828_427_124_746_190_3),
+                Some(3.098_386_676_965_933_6),
+                Some(3.265_986_323_710_904),
+                Some(2.376_354_103_144_018_3),
+                Some(1.913_066_660_344_281_2),
+                Some(1.930_666_342_865_210_7),
             ]),
             EPS
         );
@@ -663,12 +664,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, true, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.94280904158206335630),
-                Some(0.94280904158206335630),
-                Some(0.94280904158206335630),
-                Some(2.71052370871575343259),
-                Some(1.88561808316412671260),
+                Some(0.0),
+                Some(0.942_809_041_582_063_4),
+                Some(0.942_809_041_582_063_4),
+                Some(0.942_809_041_582_063_4),
+                Some(2.710_523_708_715_753_4),
+                Some(1.885_618_083_164_126_7),
             ]),
             EPS
         );
@@ -676,12 +677,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.94280904158206335630),
-                Some(0.94280904158206335630),
-                Some(0.94280904158206335630),
-                Some(1.98051449707650295551),
-                Some(1.59680573109822199207),
+                Some(0.0),
+                Some(0.942_809_041_582_063_4),
+                Some(0.942_809_041_582_063_4),
+                Some(0.942_809_041_582_063_4),
+                Some(1.980_514_497_076_503),
+                Some(1.596_805_731_098_222),
             ]),
             EPS
         );
@@ -689,12 +690,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, true, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(3.58568582800318091941),
-                Some(2.39045721866878713158),
+                Some(0.0),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(3.585_685_828_003_181),
+                Some(2.390_457_218_668_787),
             ]),
             EPS
         );
@@ -702,12 +703,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, true, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(3.76297754444535526019),
-                Some(2.24488611689135586502),
+                Some(0.0),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(3.762_977_544_445_355_3),
+                Some(2.244_886_116_891_356),
             ]),
             EPS
         );
@@ -715,12 +716,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, false, true, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(2.59807621135331601181),
-                Some(1.85404962177391574585),
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(2.598_076_211_353_316),
+                Some(1.854_049_621_773_915_7),
             ]),
             EPS
         );
@@ -728,12 +729,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, false, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(1.00000000000000000000),
-                Some(2.04939015319191986109),
-                Some(1.76068168616590092768),
+                Some(0.0),
+                Some(1.0),
+                Some(1.0),
+                Some(1.0),
+                Some(2.049_390_153_191_92),
+                Some(1.760_681_686_165_901),
             ]),
             EPS
         );
@@ -741,12 +742,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, false, false, 0, true),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(3.28633534503099689061),
-                Some(2.28868854108531749603),
+                Some(0.0),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(3.286_335_345_030_997),
+                Some(2.288_688_541_085_317_5),
             ]),
             EPS
         );
@@ -754,12 +755,12 @@ mod test {
             ewm_std(YS.to_vec(), ALPHA, false, false, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(1.41421356237309514547),
-                Some(3.51467511677403665615),
-                Some(2.30198724999625037313),
+                Some(0.0),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(SQRT_2),
+                Some(3.514_675_116_774_036_7),
+                Some(2.301_987_249_996_250_4),
             ]),
             EPS
         );
@@ -771,12 +772,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, true, 0, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(3.92243767313019331411),
-                Some(2.54978854286812728347),
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(3.922_437_673_130_193_3),
+                Some(2.549_788_542_868_127_3),
             ]),
             EPS
         );
@@ -784,12 +785,12 @@ mod test {
             ewm_var(YS.to_vec(), ALPHA, true, true, 1, false),
             PrimitiveArray::from([
                 None,
-                Some(0.00000000000000000000),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(3.92243767313019331411),
-                Some(2.54978854286812728347),
+                Some(0.0),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(3.922_437_673_130_193_3),
+                Some(2.549_788_542_868_127_3),
             ]),
             EPS
         );
@@ -798,11 +799,11 @@ mod test {
             PrimitiveArray::from([
                 None,
                 None,
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(0.88888888888888895057),
-                Some(3.92243767313019331411),
-                Some(2.54978854286812728347),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(0.888_888_888_888_889),
+                Some(3.922_437_673_130_193_3),
+                Some(2.549_788_542_868_127_3),
             ]),
             EPS
         );
