@@ -1109,11 +1109,11 @@ mod test {
         // chunked array comparison.
 
         // two same chunked arrays
-        let a1: Int32Chunked = (&[Some(1), None, Some(3)]).iter().copied().collect();
-        let a2: Int32Chunked = (&[Some(1), Some(2), Some(3)]).iter().copied().collect();
+        let a1: Int32Chunked = [Some(1), None, Some(3)].iter().copied().collect();
+        let a2: Int32Chunked = [Some(1), Some(2), Some(3)].iter().copied().collect();
 
-        let mut a2_2chunks: Int32Chunked = (&[Some(1), Some(2)]).iter().copied().collect();
-        a2_2chunks.append(&(&[Some(3)]).iter().copied().collect());
+        let mut a2_2chunks: Int32Chunked = [Some(1), Some(2)].iter().copied().collect();
+        a2_2chunks.append(&[Some(3)].iter().copied().collect());
 
         assert_eq!(
             a1.equal(&a2).into_iter().collect::<Vec<_>>(),
@@ -1170,9 +1170,9 @@ mod test {
     fn test_left_right() {
         // This failed with arrow comparisons.
         // sliced
-        let a1: Int32Chunked = (&[Some(1), Some(2)]).iter().copied().collect();
+        let a1: Int32Chunked = [Some(1), Some(2)].iter().copied().collect();
         let a1 = a1.slice(1, 1);
-        let a2: Int32Chunked = (&[Some(2)]).iter().copied().collect();
+        let a2: Int32Chunked = [Some(2)].iter().copied().collect();
         assert_eq!(a1.equal(&a2).sum(), a2.equal(&a1).sum());
         assert_eq!(a1.not_equal(&a2).sum(), a2.not_equal(&a1).sum());
         assert_eq!(a1.gt(&a2).sum(), a2.gt(&a1).sum());
@@ -1180,9 +1180,9 @@ mod test {
         assert_eq!(a1.lt_eq(&a2).sum(), a2.lt_eq(&a1).sum());
         assert_eq!(a1.gt_eq(&a2).sum(), a2.gt_eq(&a1).sum());
 
-        let a1: Utf8Chunked = (&["a", "b"]).iter().copied().collect();
+        let a1: Utf8Chunked = ["a", "b"].iter().copied().collect();
         let a1 = a1.slice(1, 1);
-        let a2: Utf8Chunked = (&["b"]).iter().copied().collect();
+        let a2: Utf8Chunked = ["b"].iter().copied().collect();
         assert_eq!(a1.equal(&a2).sum(), a2.equal(&a1).sum());
         assert_eq!(a1.not_equal(&a2).sum(), a2.not_equal(&a1).sum());
         assert_eq!(a1.gt(&a2).sum(), a2.gt(&a1).sum());
