@@ -160,12 +160,15 @@ pub(crate) mod private {
         fn group_tuples(&self, _multithreaded: bool, _sorted: bool) -> PolarsResult<GroupsProxy> {
             invalid_operation_panic!(group_tuples, self)
         }
+        #[cfg(feature = "zip_with")]
         fn zip_with_same_type(
             &self,
             _mask: &BooleanChunked,
             _other: &Series,
-        ) -> PolarsResult<Series>;
-        #[cfg(feature = "sort_multiple")]
+        ) -> PolarsResult<Series> {
+            invalid_operation_panic!(zip_with_same_type, self)
+        }
+
         fn arg_sort_multiple(&self, _by: &[Series], _descending: &[bool]) -> PolarsResult<IdxCa> {
             polars_bail!(opq = arg_sort_multiple, self._dtype());
         }
@@ -376,12 +379,12 @@ pub trait SeriesTrait:
 
     /// Get unique values in the Series.
     fn n_unique(&self) -> PolarsResult<usize> {
-        invalid_operation_panic!(n_unique, self)
+        polars_bail!(opq = n_unique, self._dtype());
     }
 
     /// Get first indexes of unique values.
     fn arg_unique(&self) -> PolarsResult<IdxCa> {
-        invalid_operation_panic!(arg_unique, self)
+        polars_bail!(opq = arg_unique, self._dtype());
     }
 
     /// Get a mask of the null values.
@@ -432,15 +435,15 @@ pub trait SeriesTrait:
     /// If the [`DataType`] is one of `{Int8, UInt8, Int16, UInt16}` the `Series` is
     /// first cast to `Int64` to prevent overflow issues.
     fn _sum_as_series(&self) -> Series {
-        invalid_operation_panic!(_sum_as_series, self)
+        Series::full_null(self.name(), 1, self.dtype())
     }
     /// Get the max of the Series as a new Series of length 1.
     fn max_as_series(&self) -> Series {
-        invalid_operation_panic!(max_as_series, self)
+        Series::full_null(self.name(), 1, self.dtype())
     }
     /// Get the min of the Series as a new Series of length 1.
     fn min_as_series(&self) -> Series {
-        invalid_operation_panic!(min_as_series, self)
+        Series::full_null(self.name(), 1, self.dtype())
     }
     /// Get the median of the Series as a new Series of length 1.
     fn median_as_series(&self) -> Series {
@@ -503,7 +506,7 @@ pub trait SeriesTrait:
     /// Check if elements of this Series are in the right Series, or List values of the right Series.
     #[cfg(feature = "is_in")]
     fn is_in(&self, _other: &Series) -> PolarsResult<BooleanChunked> {
-        invalid_operation_panic!(is_in, self)
+        polars_bail!(opq = is_in, self._dtype());
     }
     #[cfg(feature = "repeat_by")]
     fn repeat_by(&self, _by: &IdxCa) -> ListChunked {
@@ -511,13 +514,13 @@ pub trait SeriesTrait:
     }
     #[cfg(feature = "checked_arithmetic")]
     fn checked_div(&self, _rhs: &Series) -> PolarsResult<Series> {
-        invalid_operation_panic!(checked_div, self)
+        polars_bail!(opq = checked_div, self._dtype());
     }
 
     #[cfg(feature = "mode")]
     /// Compute the most occurring element in the array.
     fn mode(&self) -> PolarsResult<Series> {
-        invalid_operation_panic!(mode, self);
+        polars_bail!(opq = mode, self._dtype());
     }
 
     #[cfg(feature = "rolling_window")]
@@ -528,7 +531,7 @@ pub trait SeriesTrait:
         _f: &dyn Fn(&Series) -> Series,
         _options: RollingOptionsFixedWindow,
     ) -> PolarsResult<Series> {
-        invalid_operation_panic!(rolling_apply, self);
+        polars_bail!(opq = rolling_apply, self._dtype());
     }
     #[cfg(feature = "concat_str")]
     /// Concat the values into a string array.
