@@ -7,6 +7,7 @@ use polars_core::datatypes::PlHashSet;
 use polars_core::prelude::*;
 #[cfg(feature = "polars-time")]
 use polars_time::chunkedarray::utf8::infer as date_infer;
+use polars_time::chunkedarray::utf8::PatternWithOffset;
 #[cfg(feature = "polars-time")]
 use polars_time::prelude::utf8::Pattern;
 use regex::{Regex, RegexBuilder};
@@ -110,10 +111,23 @@ fn infer_field_schema(string: &str, try_parse_dates: bool) -> DataType {
             #[cfg(feature = "polars-time")]
             {
                 match date_infer::infer_pattern_single(&string[1..string.len() - 1]) {
-                    Some(Pattern::DatetimeYMD | Pattern::DatetimeDMY) => {
-                        DataType::Datetime(TimeUnit::Microseconds, None)
-                    }
-                    Some(Pattern::DateYMD | Pattern::DateDMY) => DataType::Date,
+                    Some(pattern_with_offset) => match pattern_with_offset {
+                        PatternWithOffset {
+                            pattern: Pattern::DatetimeYMD | Pattern::DatetimeDMY,
+                            offset: _,
+                        } => DataType::Datetime(TimeUnit::Microseconds, None),
+                        PatternWithOffset {
+                            pattern: Pattern::DateYMD | Pattern::DateDMY,
+                            offset: _,
+                        } => DataType::Date,
+                        PatternWithOffset {
+                            pattern: Pattern::DatetimeYMDZ,
+                            offset,
+                        } => DataType::Datetime(
+                            TimeUnit::Microseconds,
+                            offset.map(|x| x.to_string()),
+                        ),
+                    },
                     None => DataType::Utf8,
                 }
             }
@@ -136,10 +150,20 @@ fn infer_field_schema(string: &str, try_parse_dates: bool) -> DataType {
         #[cfg(feature = "polars-time")]
         {
             match date_infer::infer_pattern_single(string) {
-                Some(Pattern::DatetimeYMD | Pattern::DatetimeDMY) => {
-                    DataType::Datetime(TimeUnit::Microseconds, None)
-                }
-                Some(Pattern::DateYMD | Pattern::DateDMY) => DataType::Date,
+                Some(pattern_with_offset) => match pattern_with_offset {
+                    PatternWithOffset {
+                        pattern: Pattern::DatetimeYMD | Pattern::DatetimeDMY,
+                        offset: _,
+                    } => DataType::Datetime(TimeUnit::Microseconds, None),
+                    PatternWithOffset {
+                        pattern: Pattern::DateYMD | Pattern::DateDMY,
+                        offset: _,
+                    } => DataType::Date,
+                    PatternWithOffset {
+                        pattern: Pattern::DatetimeYMDZ,
+                        offset,
+                    } => DataType::Datetime(TimeUnit::Microseconds, offset.map(|x| x.to_string())),
+                },
                 None => DataType::Utf8,
             }
         }
