@@ -155,7 +155,9 @@ impl ApplyExpr {
             }
             AggState::AggregatedFlat(s) => (self.eval_and_flatten(&mut [s.clone()])?, true),
             AggState::NotAggregated(s) | AggState::Literal(s) => {
-                (self.eval_and_flatten(&mut [s.clone()])?, false)
+                let (out, aggregated) = (self.eval_and_flatten(&mut [s.clone()])?, false);
+                check_map_output_len(s.len(), out.len(), &self.expr)?;
+                (out, aggregated)
             }
         };
 
@@ -222,7 +224,7 @@ fn all_unit_length(ca: &ListChunked) -> bool {
 
 fn check_map_output_len(input_len: usize, output_len: usize, expr: &Expr) -> PolarsResult<()> {
     polars_ensure!(
-        input_len == output_len, expr = expr, ComputeError:
+        input_len == output_len, expr = expr, InvalidOperation:
         "output length of `map` must be equal to that of the input length; \
         consider using `apply` instead"
     );
@@ -312,9 +314,9 @@ impl PhysicalExpr for ApplyExpr {
         };
 
         match function {
-            FunctionExpr::IsNull => Some(self),
+            FunctionExpr::Boolean(BooleanFunction::IsNull) => Some(self),
             #[cfg(feature = "is_in")]
-            FunctionExpr::IsIn => Some(self),
+            FunctionExpr::Boolean(BooleanFunction::IsIn) => Some(self),
             _ => None,
         }
     }
@@ -409,7 +411,7 @@ impl ApplyExpr {
         };
 
         match function {
-            FunctionExpr::IsNull => {
+            FunctionExpr::Boolean(BooleanFunction::IsNull) => {
                 let root = expr_to_leaf_column_name(&self.expr)?;
 
                 match stats.get_stats(&root).ok() {
@@ -421,7 +423,7 @@ impl ApplyExpr {
                 }
             }
             #[cfg(feature = "is_in")]
-            FunctionExpr::IsIn => {
+            FunctionExpr::Boolean(BooleanFunction::IsIn) => {
                 let root = match expr_to_leaf_column_name(&input[0]) {
                     Ok(root) => root,
                     Err(_) => return Ok(true),
