@@ -7,12 +7,14 @@ pub trait SExecutionContext: Send + Sync {
 pub struct PExecutionContext {
     // injected upstream in polars-lazy
     pub(crate) execution_state: Box<dyn SExecutionContext>,
+    pub(crate) verbose: bool,
 }
 
 impl PExecutionContext {
-    pub(crate) fn new(state: Box<dyn SExecutionContext>) -> Self {
+    pub(crate) fn new(state: Box<dyn SExecutionContext>, verbose: bool) -> Self {
         PExecutionContext {
             execution_state: state,
+            verbose,
         }
     }
 }
