@@ -104,13 +104,13 @@ impl FunctionExpr {
 
         use FunctionExpr::*;
         match self {
+            #[cfg(feature = "abs")]
+            Abs => same_type(),
             NullCount => with_dtype(IDX_DTYPE),
             Pow => float_dtype(),
             Coalesce => super_type(),
             #[cfg(feature = "row_hash")]
             Hash(..) => with_dtype(DataType::UInt64),
-            #[cfg(feature = "is_in")]
-            IsIn => with_dtype(DataType::Boolean),
             #[cfg(feature = "arg_where")]
             ArgWhere => with_dtype(IDX_DTYPE),
             #[cfg(feature = "search_sorted")]
@@ -154,6 +154,13 @@ impl FunctionExpr {
                     Month | Quarter | Week | WeekDay | Day | OrdinalDay | Hour | Minute
                     | Millisecond | Microsecond | Nanosecond | Second => DataType::UInt32,
                     TimeStamp(_) => DataType::Int64,
+                    IsLeapYear => DataType::Boolean,
+                    Time => DataType::Time,
+                    Date => DataType::Date,
+                    Datetime => match same_type().unwrap().dtype {
+                        DataType::Datetime(tu, _) => DataType::Datetime(tu, None),
+                        dtype => polars_bail!(ComputeError: "expected Datetime, got {}", dtype),
+                    },
                     Truncate(..) => same_type().unwrap().dtype,
                     Round(..) => same_type().unwrap().dtype,
                     #[cfg(feature = "timezones")]
@@ -176,7 +183,7 @@ impl FunctionExpr {
             #[cfg(all(feature = "rolling_window", feature = "moment"))]
             RollingSkew { .. } => float_dtype(),
             ShiftAndFill { .. } => same_type(),
-            Nan(n) => n.get_field(fields),
+            DropNans => same_type(),
             #[cfg(feature = "round_series")]
             Clip { .. } => same_type(),
             ListExpr(l) => {
@@ -234,9 +241,12 @@ impl FunctionExpr {
             #[cfg(feature = "top_k")]
             TopK { .. } => same_type(),
             Shift(..) | Reverse => same_type(),
-            IsNotNull | IsNull | Not => with_dtype(DataType::Boolean),
-            #[cfg(feature = "is_unique")]
-            IsUnique | IsDuplicated => with_dtype(DataType::Boolean),
+            Boolean(f) => with_dtype(f.dtype_out()),
+            Cumcount { .. } => with_dtype(IDX_DTYPE),
+            Cumsum { .. } => map_dtype(&cum::dtypes::cumsum),
+            Cumprod { .. } => map_dtype(&cum::dtypes::cumprod),
+            Cummin { .. } => same_type(),
+            Cummax { .. } => same_type(),
             #[cfg(feature = "diff")]
             Diff(_, _) => map_dtype(&|dt| match dt {
                 #[cfg(feature = "dtype-datetime")]
@@ -284,7 +294,8 @@ impl FunctionExpr {
                 }
             }),
             #[cfg(feature = "log")]
-            Entropy { .. } => float_dtype(),
+            Entropy { .. } | Log { .. } | Log1p | Exp => float_dtype(),
+            Unique(_) => same_type(),
         }
     }
 }
