@@ -1,4 +1,3 @@
-use std::borrow::Cow;
 use std::fmt::Debug;
 #[cfg(any(feature = "ipc", feature = "csv-file", feature = "parquet"))]
 use std::path::PathBuf;
@@ -71,7 +70,20 @@ pub enum ErrorState {
     AlreadyEncountered { prev_err_msg: String },
 }
 
-#[derive(Debug, Clone)]
+impl std::fmt::Display for ErrorState {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            ErrorState::NotYetEncountered { err } => write!(f, "NotYetEncountered({err})")?,
+            ErrorState::AlreadyEncountered { prev_err_msg } => {
+                write!(f, "AlreadyEncountered({prev_err_msg})")?
+            }
+        };
+
+        Ok(())
+    }
+}
+
+#[derive(Clone)]
 pub struct ErrorStateSync(Arc<Mutex<ErrorState>>);
 
 impl std::ops::Deref for ErrorStateSync {
@@ -82,20 +94,30 @@ impl std::ops::Deref for ErrorStateSync {
     }
 }
 
+impl std::fmt::Debug for ErrorStateSync {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "ErrorStateSync({})", &*self.0.lock().unwrap())
+    }
+}
+
 impl ErrorStateSync {
     fn take(&self) -> PolarsError {
-        let mut err = self.0.lock().unwrap();
-        match &*err {
+        let mut curr_err = self.0.lock().unwrap();
+
+        match &*curr_err {
             ErrorState::NotYetEncountered { err: polars_err } => {
-                let msg = format!("{polars_err:?}");
-                let err = std::mem::replace(
-                    &mut *err,
-                    ErrorState::AlreadyEncountered { prev_err_msg: msg },
+                // Need to finish using `polars_err` here so that NLL considers `err` dropped
+                let prev_err_msg = polars_err.to_string();
+                // Place AlreadyEncountered in `self` for future users of `self`
+                let prev_err = std::mem::replace(
+                    &mut *curr_err,
+                    ErrorState::AlreadyEncountered { prev_err_msg },
                 );
-                let ErrorState::NotYetEncountered { err } = err else {
-                    unreachable!("polars bug in LogicalPlan error handling")
-                };
-                err
+                // Since we're in this branch, we know err was a NotYetEncountered
+                match prev_err {
+                    ErrorState::NotYetEncountered { err } => err,
+                    ErrorState::AlreadyEncountered { .. } => unreachable!(),
+                }
             }
             ErrorState::AlreadyEncountered { prev_err_msg } => {
                 polars_err!(
@@ -269,43 +291,6 @@ impl Default for LogicalPlan {
 }
 
 impl LogicalPlan {
-    pub fn schema(&self) -> PolarsResult<Cow<'_, SchemaRef>> {
-        use LogicalPlan::*;
-        match self {
-            #[cfg(feature = "python")]
-            PythonScan { options } => Ok(Cow::Borrowed(&options.schema)),
-            Union { inputs, .. } => inputs[0].schema(),
-            Cache { input, .. } => input.schema(),
-            Sort { input, .. } => input.schema(),
-            #[cfg(feature = "parquet")]
-            ParquetScan { file_info, .. } => Ok(Cow::Borrowed(&file_info.schema)),
-            #[cfg(feature = "ipc")]
-            IpcScan { file_info, .. } => Ok(Cow::Borrowed(&file_info.schema)),
-            DataFrameScan { schema, .. } => Ok(Cow::Borrowed(schema)),
-            AnonymousScan { file_info, .. } => Ok(Cow::Borrowed(&file_info.schema)),
-            Selection { input, .. } => input.schema(),
-            #[cfg(feature = "csv-file")]
-            CsvScan { file_info, .. } => Ok(Cow::Borrowed(&file_info.schema)),
-            Projection { schema, .. } => Ok(Cow::Borrowed(schema)),
-            LocalProjection { schema, .. } => Ok(Cow::Borrowed(schema)),
-            Aggregate { schema, .. } => Ok(Cow::Borrowed(schema)),
-            Join { schema, .. } => Ok(Cow::Borrowed(schema)),
-            HStack { schema, .. } => Ok(Cow::Borrowed(schema)),
-            Distinct { input, .. } | FileSink { input, .. } => input.schema(),
-            Slice { input, .. } => input.schema(),
-            MapFunction {
-                input, function, ..
-            } => {
-                let input_schema = input.schema()?;
-                match input_schema {
-                    Cow::Owned(schema) => Ok(Cow::Owned(function.schema(&schema)?.into_owned())),
-                    Cow::Borrowed(schema) => function.schema(schema),
-                }
-            }
-            Error { err, .. } => Err(err.take()),
-            ExtContext { schema, .. } => Ok(Cow::Borrowed(schema)),
-        }
-    }
     pub fn describe(&self) -> String {
         format!("{self:#?}")
     }
