@@ -17,8 +17,11 @@ from polars.utils.convert import (
 )
 from polars.utils.meta import get_idx_type, get_index_type, threadpool_size
 from polars.utils.show_versions import show_versions
+from polars.utils.various import NoDefault, no_default
 
 __all__ = [
+    "NoDefault",
+    "no_default",
     "build_info",
     "show_versions",
     "get_idx_type",
