@@ -724,6 +724,7 @@ impl PyExpr {
     }
 
     #[pyo3(signature = (pat, literal, strict))]
+    #[cfg(feature = "lazy_regex")]
     pub fn str_contains(&self, pat: PyExpr, literal: Option<bool>, strict: bool) -> PyExpr {
         match literal {
             Some(true) => self.inner.clone().str().contains_literal(pat.inner).into(),
@@ -863,6 +864,7 @@ impl PyExpr {
             .into()
     }
 
+    #[cfg(feature = "extract_jsonpath")]
     pub fn str_json_extract(&self, dtype: Option<Wrap<DataType>>) -> PyExpr {
         let dtype = dtype.map(|wrap| wrap.0);
 
@@ -1580,7 +1582,7 @@ impl PyExpr {
         self.inner.clone().arr().arg_max().into()
     }
 
-    fn lst_diff(&self, n: usize, null_behavior: Wrap<NullBehavior>) -> PyResult<Self> {
+    fn lst_diff(&self, n: i64, null_behavior: Wrap<NullBehavior>) -> PyResult<Self> {
         Ok(self.inner.clone().arr().diff(n, null_behavior.0).into())
     }
 
@@ -1645,12 +1647,12 @@ impl PyExpr {
         self.inner.clone().rank(options, seed).into()
     }
 
-    fn diff(&self, n: usize, null_behavior: Wrap<NullBehavior>) -> Self {
+    fn diff(&self, n: i64, null_behavior: Wrap<NullBehavior>) -> Self {
         self.inner.clone().diff(n, null_behavior.0).into()
     }
 
     #[cfg(feature = "pct_change")]
-    fn pct_change(&self, n: usize) -> Self {
+    fn pct_change(&self, n: i64) -> Self {
         self.inner.clone().pct_change(n).into()
     }
 
@@ -1807,6 +1809,10 @@ impl PyExpr {
         self.inner.clone().log(base).into()
     }
 
+    pub fn log1p(&self) -> Self {
+        self.inner.clone().log1p().into()
+    }
+
     pub fn exp(&self) -> Self {
         self.inner.clone().exp().into()
     }
