@@ -22,3 +22,11 @@ def test_empty_cross_join() -> None:
     b = pl.LazyFrame(schema={"b": pl.Int32})
 
     assert (a.join(b, how="cross").collect()).schema == {"a": pl.Int32, "b": pl.Int32}
+
+
+def test_empty_string_replace() -> None:
+    s = pl.Series("", [], dtype=pl.Utf8)
+    assert s.str.replace("a", "b", literal=True).series_equal(s)
+    assert s.str.replace("a", "b").series_equal(s)
+    assert s.str.replace("ab", "b", literal=True).series_equal(s)
+    assert s.str.replace("ab", "b").series_equal(s)
